@@ -1,6 +1,6 @@
 /* 
  * Copyright 2004-2009 Rob Beverly
- * Copyright 2015-2020 The Regents of the University of California
+ * Copyright 2015-2022 The Regents of the University of California
  * All rights reserved.
  * 
  * This file is part of Spoofer.
@@ -30,10 +30,10 @@
  */
 
 /****************************************************************************
-   Program:     $Id: net.cc,v 1.171 2020/07/16 19:23:36 kkeys Exp $
+   Program:     $Id: net.cc,v 1.175 2022/02/07 19:48:20 kkeys Exp $
    Author:      Rob Beverly <rbeverly at csail.mit.edu>
                 Ken Keys, CAIDA
-   Date:        $Date: 2020/07/16 19:23:36 $
+   Date:        $Date: 2022/02/07 19:48:20 $
    Description: Spoofer utility routines
 ****************************************************************************/
 #include <stdarg.h>
@@ -49,8 +49,10 @@ static const int always_verify = 0;
 
 static bool spoof_rawip_send(socket_t spoofsock, socket_t udpsock,
     const void *msg, size_t len, probe_info *pinfo, ssize_t sniff_len);
+#ifdef HAVE_PCAP
 static bool spoof_pcap_send(socket_t spoofsock, socket_t udpsock,
     const void *msg, size_t len, probe_info *pinfo, ssize_t sniff_len);
+#endif
 
 struct spoof_api_info {
     const int layer;
@@ -382,7 +384,6 @@ done:
 	ntopBuf(sa)(), ifname ? ifname : "(NONE)");
     return ifname;
 }
-#endif // HAVE_PCAP
 
 static unsigned count_leading_ones(const void *data, size_t len)
 {
@@ -398,6 +399,7 @@ static unsigned count_leading_ones(const void *data, size_t len)
     }
     return n;
 }
+#endif // HAVE_PCAP
 
 void dump_ifaces()
 {
@@ -550,19 +552,28 @@ bool init_sniffer(struct probe_info *pinfo, size_t pay_len)
 	print_pcap_error(pinfo->sniffer, rc, "%s: pcap_set_snaplen", ifname);
 	if (rc < 0) goto error; // error
     }
+#ifdef HAVE_PCAP_SET_IMMEDIATE_MODE
+    // Tell pcap to deliver packets immediately, instead of buffering them.
+    // (Necessary on linux in libpcap >1.9 (with TPACKET_V3), maybe elsewhere)
+    rc = pcap_set_immediate_mode(pinfo->sniffer, 1);
+    if (rc != 0) { // error or warning
+	print_pcap_error(pinfo->sniffer, rc, "%s: pcap_set_immediate_mode", ifname);
+	if (rc < 0) goto error; // error
+    }
+#endif // HAVE_PCAP_SET_IMMEDIATE_MODE
     debug(DEVELOP, ">> init_sniffer: pcap_activate\n");
     rc = pcap_activate(pinfo->sniffer);
     if (rc != 0) { // error or warning
 	print_pcap_error(pinfo->sniffer, rc, "%s: pcap_activate", ifname);
 	if (rc < 0) goto error; // error
     }
-#else
+#else // !HAVE_PCAP_CREATE
     pinfo->sniffer = pcap_open_live(ifname, snaplen, 0, 0, errbuf);
     if (!pinfo->sniffer) {
 	printf("error in pcap_open_live: %s\n", errbuf);
 	goto error;
     }
-#endif
+#endif // HAVE_PCAP_CREATE
     if (pcap_setnonblock(pinfo->sniffer, 1, errbuf) < 0) {
 	printf("error in pcap_setnonblock: %s\n", errbuf);
 	goto error;
@@ -1007,9 +1018,9 @@ done:
 
 enum ProbeStatus free_probe_info(struct probe_info *pinfo, bool skipSniffing)
 {
+#ifdef HAVE_PCAP
     if (pinfo->pilot_pinfo)
 	free_probe_info(pinfo->pilot_pinfo, true);
-#ifdef HAVE_PCAP
     if (pinfo->sniffer && !skipSniffing)
 	egress_pcap_dispatch(pinfo, "free_probe_info");
     pinfo->free_sniffer();
@@ -1671,6 +1682,7 @@ int socketSendSpoof(socket_t spoofsock, socket_t udpsock, const void *msg,
 	return -1;
     }
 
+#ifdef HAVE_PCAP
     if (!pinfo->rtinfo || !pinfo->rtinfo->ifinfo) {
 	// use the pilot socket to fill in rtinfo and ifinfo
 	pinfo->pilot_pinfo =
@@ -1678,6 +1690,7 @@ int socketSendSpoof(socket_t spoofsock, socket_t udpsock, const void *msg,
 	if (!pinfo->pilot_pinfo) return -1;
 	pinfo->rtinfo = pinfo->pilot_pinfo->rtinfo;
     }
+#endif
 
     for (int pref = 0; spoof_apis[pref].send; pref++) {
 	spoof_api_info &api = spoof_apis[pref];
@@ -1742,8 +1755,10 @@ static bool spoof_rawip_send(socket_t spoofsock, socket_t udpsock ATR_UNUSED,
     ssize_t rc;
     const sockaddr *dst = pinfo->dst_sa;
 
+#ifdef HAVE_PCAP
     if (sniff_len >= 0)
 	init_sniffer(pinfo, safe_int<size_t>(sniff_len));
+#endif
 
 #ifdef _BSD /* BSD raw (ip) sockets expect ip_len and ip_off in host order */
     uint32_t *bsd_msg = new uint32_t[(len+3)/4]; // uint32 for alignment
