@@ -1,5 +1,5 @@
 /* 
- * Copyright 2015-2020 The Regents of the University of California
+ * Copyright 2015-2022 The Regents of the University of California
  * All rights reserved.
  * 
  * This file is part of Spoofer.
@@ -38,7 +38,7 @@
 #endif
 #include "../../config.h"
 #include "common.h"
-static const char cvsid[] ATR_USED = "$Id: common.cpp,v 1.91 2020/07/16 19:23:40 kkeys Exp $";
+static const char cvsid[] ATR_USED = "$Id: common.cpp,v 1.94 2022/03/04 23:48:09 kkeys Exp $";
 
 SpooferBase::OnDemandDevice SpooferBase::outdev(stdout);
 SpooferBase::OnDemandDevice SpooferBase::errdev(stderr);
@@ -50,7 +50,7 @@ SpooferBase::Config *SpooferBase::config;
 QSettings *SpooferBase::Config::settings;
 QList<SpooferBase::Config::MemberBase*> SpooferBase::Config::members;
 
-// We avoid ".log" Suffix because OSX "open" would launch a log reader app
+// We avoid ".log" Suffix because macOS "open" would launch a log reader app
 // we don't want.
 const QString SpooferBase::proberLogFtime = QSL("'spoofer-prober-'yyyy~MM~dd-HH~mm~ss'.txt'");
 const QString SpooferBase::proberLogGlob = QSL("spoofer-prober-\?\?\?\?\?\?\?\?-\?\?\?\?\?\?.txt"); // backslashes prevent trigraphs
@@ -163,7 +163,7 @@ SpooferBase::Config::Config() :
  #if defined(Q_OS_WIN32)
 	QSL("add Windows MOTW to downloaded installer")),
  #elif defined(Q_OS_MACOS)
-	QSL("add OSX quarantine attribute to downloaded installer")),
+	QSL("add macOS quarantine attribute to downloaded installer")),
  #else
 	QSL("not used")),
  #endif // Q_OS_MACOS
