@@ -1,5 +1,5 @@
 /* 
- * Copyright 2015-2020 The Regents of the University of California
+ * Copyright 2015-2022 The Regents of the University of California
  * All rights reserved.
  * 
  * This file is part of Spoofer.
@@ -47,7 +47,7 @@
 #include "PreferencesDialog.h"
 #include "ColoredLabel.h"
 #include "SubnetAddr.h"
-static const char cvsid[] ATR_USED = "$Id: mainwindow.cpp,v 1.223 2020/07/16 19:23:42 kkeys Exp $";
+static const char cvsid[] ATR_USED = "$Id: mainwindow.cpp,v 1.227 2022/03/05 01:07:56 kkeys Exp $";
 
 #define HISTORYTABLE_BGCOLOR "#EEEEEE"
 
@@ -294,8 +294,8 @@ MainWindow::MainWindow(QWidget *_parent) :
     XX(routable,     "outbound\nroutable","Result of client sending packets to server with spoofed routable addresses") \
     XX(inprivaddr,   "inbound\nprivate",  "Result of server sending packets to client with spoofed private addresses") \
     XX(ininternal,   "inbound\ninternal", "Result of server sending packets to client with spoofed internal (same subnet as client) addresses") \
-    XX(report,       "report",            "Summary report at website") \
-    XX(log,          "log",               "Prober technical log (click to hide)") \
+    XX(report,       "report",            "View summary report at website") \
+    XX(log,          "log",               "View prober technical log (click to hide)") \
     XX(showlog,      CHAR_ARROW_RT,       "Click to show logs")
 
 enum historyColumnId {
@@ -480,11 +480,11 @@ void MainWindow::init()
 
     //========= menubar
     // Note: menubar->addAction() may work on some platforms, but does not
-    // work at all on OSX; only QMenus can be added to menubar.
+    // work at all on macOS; only QMenus can be added to menubar.
     // (Toolbars, OTOH, can contain actions and widgets but not menus.)
     QMenuBar *menubar = this->menuBar();
 
-    // Note: on OSX, Qt will move the special entries "about", "exit", and
+    // Note: on macOS, Qt will move the special entries "about", "exit", and
     // "preferences" out to the OS menu unless their role is changed.
 #ifdef Q_OS_MACOS
     QMenu *spooferMenu = new QMenu(QSL("Preferences"));
