@@ -1,6 +1,6 @@
 /* 
  * Copyright 2004-2009 Rob Beverly
- * Copyright 2015-2020 The Regents of the University of California
+ * Copyright 2015-2022 The Regents of the University of California
  * All rights reserved.
  * 
  * This file is part of Spoofer.
@@ -32,7 +32,7 @@
 /****************************************************************************
    Author:      Rob Beverly <rbeverly at csail.mit.edu>
                 Ken Keys, CAIDA
-   Date:        $Date: 2020/07/22 22:24:50 $
+   Date:        $Date: 2022/03/04 23:48:10 $
    Description: Spoofer - generate spoofed packets
 ****************************************************************************/
 
@@ -81,7 +81,7 @@ static bool multiThreaded = true;
 static bool multiThreaded = false;
 #endif
 
-static const char cvsid[] ATR_USED = "$Id: spoofer-prober.cc,v 1.237 2020/07/22 22:24:50 kkeys Exp $";
+static const char cvsid[] ATR_USED = "$Id: spoofer-prober.cc,v 1.241 2022/03/04 23:48:10 kkeys Exp $";
 
 static int sharePublic = -1; // initially unknown
 static int shareRemedy = -1; // initially unknown
@@ -1918,7 +1918,7 @@ NORETURN static void usage(char *prog, int exitcode, bool showHidden = false) {
     printf("-6          test IPv6 (default: both IPv4 and IPv6)\n");
     printf("-L<n>       spoof with layer <n> API: 3 (IP), 2 (link), or 0 (auto).\n");
 #ifdef HAVE_PTHREAD
-    printf("-1          run single-threaded\n");
+    printf("-1          run single-threaded (reduces network bandwidth and memory use\n");
 #endif
 #ifdef HAVE_LIBSSL
     printf("--no-tls           connect to server without SSL/TLS\n");
@@ -2222,11 +2222,11 @@ int main(int argc, char **argv) {
 
 #ifdef _OSX
 	    char ca_file_buf[PATH_MAX];
-	    // Export OSX root certificates to a file that openssl can load.
+	    // Export macOS root certificates to a file that openssl can load.
 	    char tmp[PATH_MAX];
 	    char cmd[PATH_MAX+128];
-	    snprintf(tmp, sizeof(tmp), "%s/osx_cert.tmp", AppInfo::dir());
-	    snprintf(ca_file_buf, sizeof(ca_file_buf), "%s/osx_cert.pem",
+	    snprintf(tmp, sizeof(tmp), "%s/macos_cert.tmp", AppInfo::dir());
+	    snprintf(ca_file_buf, sizeof(ca_file_buf), "%s/macos_cert.pem",
 		AppInfo::dir());
 	    snprintf(cmd, sizeof(cmd), "security find-certificate -a -p %s >%s",
 		"/System/Library/Keychains/SystemRootCertificates.keychain",
